@@ -1,3 +1,3 @@
 if (getRversion() >= '2.15.1') globalVariables(c("NofAnimals", "NofLine", "N",
-                                                 "ANOVArandom", "Coxrandom", "ANOVAfix", "Coxfix",
+                                                 "ANOVArandom", "Coxrandom",
                                                  "PDOX lines", "Number of Animals"))
